# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Module-Metadata
Version:	1.000038
Release:	1.%{__distinit}%{__distvers}
Summary:	Gather package and POD information from perl module files
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Module-Metadata
Source0:	https://cpan.metacpan.org/modules/by-module/Module/Module-Metadata-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(Carp)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(strict)
BuildRequires:	perl(version) >= 0.87
BuildRequires:	perl(warnings)
# Regular test suite
BuildRequires:	perl(Config)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(vars)
# Optional test requirements
BuildRequires:	perl(CPAN::Meta) >= 2.120900
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Encode)
Requires:	perl(Fcntl)

%description
This module provides a standard way to gather metadata about a .pm file
without executing unsafe code.

%prep
%setup -q -n Module-Metadata-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENCE
%doc Changes CONTRIBUTING README
%{perl_vendorlib}/Module/
%{_mandir}/man3/Module::Metadata.3*

%changelog
* Fri Apr 28 2023 Paul Howarth <paul@city-fan.org> - 1.000038-1
- Update to 1.000038
  - Detects "class" syntax
- Use SPDX-format license tag
- Use %%license unconditionally
- Drop support for building with rpm < 4.9

* Mon Sep  9 2019 Paul Howarth <paul@city-fan.org> - 1.000037-1
- Update to 1.000037
  - Add decode_pod option for automatic =encoding handling

* Fri Apr 19 2019 Paul Howarth <paul@city-fan.org> - 1.000036-1
- Update to 1.000036
  - Properly clean up temp dirs after testing

* Thu Apr 18 2019 Paul Howarth <paul@city-fan.org> - 1.000035-1
- Update to 1.000035
  - Fix how relative paths are absolutized, so they work properly on MSWin32
    (GH#24)
  - Quieten noisy tests (GH#31)

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.000033-416
- Perl 5.28 rebuild

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 1.000033-395
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Mon Jul 25 2016 Paul Howarth <paul@city-fan.org> - 1.000033-1
- Update to 1.000033
  - Refactor and expand test cases
  - Fix a $VERSION extraction issue on perl 5.6.2 (CPAN RT#105978, PR#17)
  - Fix the detection of package Foo when $Foo::VERSION is set (CPAN RT#85961)
  - Fix missing "use" statement in refactored test helper (only affected older
    perls, due to other module interactions)
  - Temporary directories cleaned up during tests
  - More accurately mark tests as TODO, so as to have a quieter and less
    confusing test run without passing TODO tests
  - Be less noisy on failure when building as part of perl core (see
    Perl RT#126685)
  - Use a more strict matching heuristic when attempting to infer the "primary"
    module name in a parsed .pm file
  - Only report "main" as the module name if code was seen outside another
    namespace, fixing bad results for pod files (CPAN RT#107525)
  - Fix file operation in tests for VMS
- Update patch for building with old Test::More versions
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jun 15 2015 Paul Howarth <paul@city-fan.org> - 1.000027-2
- Perl 5.22 rebuild

* Sat Apr 11 2015 Paul Howarth <paul@city-fan.org> - 1.000027-1
- Update to 1.000027
  - Work around issues with an unconfigured Log::Contextual
  - Allow tests to pass in a perl with no taint support

* Fri Jan 30 2015 Paul Howarth <paul@city-fan.org> - 1.000026-1
- Update to 1.000026
  - Patched tests to be less noisy in blead builds (CPAN RT#101491)
- Update patch for building with old Test::More versions

* Tue Jan  6 2015 Paul Howarth <paul@city-fan.org> - 1.000025-1
- Update to 1.000025
  - Evaluate version assignment in a clean environment, to fix assignment in a
    block (CPAN RT#101095)
- Use %%license where possible

* Tue Jun 10 2014 Paul Howarth <paul@city-fan.org> - 1.000024-1
- Update to 1.000024
  - Support installations on older perls with an ExtUtils::MakeMaker earlier
    than 6.63_03
- Don't bother trying to run the release tests
- Package new documentation files from upstream: CONTRIBUTING LICENSE README.md

* Wed Apr 30 2014 Paul Howarth <paul@city-fan.org> - 1.000022-1
- Update to 1.000022
  - New is_indexable() object method (CPAN RT#84357)
  - Eliminated dependency on IO::File (and by virtue, XS)
  - Removed cruft in test infrastructure left behind from separation from
    Module::Build
  - Repository moved to https://github.com/Perl-Toolchain-Gang/Module-Metadata
  - .pm file is now wholly ascii, for nicer fatpacking (CPAN RT#95086)
  - Some code micro-optimizations
    (https://github.com/Perl-Toolchain-Gang/Module-Metadata/pull/4)
  - Fixed all out of date prereq declarations
  - Work around change in comparison behaviour in Test::More 0.95_01 by being
    more explicit with our tests - now explicitly checking the string form of
    the extracted version, rather than the entire version object
  - Ensure the extracted version is returned as a version object in all cases
    (CPAN RT#87782)
- Drop %%defattr, redundant since rpm 4.4
- Update patch for building with old Test::More versions

* Sun Oct  6 2013 Paul Howarth <paul@city-fan.org> - 1.000019-1
- Update to 1.000019
  - Warnings now disabled inside during the evaluation of generated version sub
    (CPAN RT#89282)
- BR: perl(Config), perl(File::Basename) and perl(IO::File) for the test suite

* Wed Sep 11 2013 Paul Howarth <paul@city-fan.org> - 1.000018-1
- Update to 1.000018
  - Re-release of de-tainting fix without unstated non-core test dependencies
- Drop BR: perl(Test::Fatal)
- Update patch for building with old Test::More versions

* Wed Sep 11 2013 Paul Howarth <paul@city-fan.org> - 1.000017-1
- Update to 1.000017
  - De-taint version, if needed (CPAN RT#88576)
- BR: perl(Test::Fatal)
- Update patch for building with old Test::More versions

* Thu Aug 22 2013 Paul Howarth <paul@city-fan.org> - 1.000016-1
- Update to 1.000016
  - Re-release to fix prereqs and other metadata
- This release by ETHER -> update source URL
- Specify all dependencies

* Wed Aug 21 2013 Paul Howarth <paul@city-fan.org> - 1.000015-1
- Update to 1.000015
  - Change wording about safety/security to satisfy CVE-2013-1437

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 1.000014-2
- Perl 5.18 rebuild

* Thu May  9 2013 Paul Howarth <paul@city-fan.org> - 1.000014-1
- Update to 1.000014
  - Fix reliance on recent Test::Builder
  - Make tests perl 5.6 compatible
- This release by BOBTFISH -> update source URL
- Update patch for building with old Test::More versions

* Sun May  5 2013 Paul Howarth <paul@city-fan.org> - 1.000012-1
- Update to 1.000012
  - Improved package detection heuristics
  - Fix ->contains_pod (CPAN RT#84932)
  - Fix detection of pod after __END__ (CPAN RT#79656)
- This release by ETHER -> update source URL
- Package new upstream README file
- Update patch for building with old Test::More versions

* Tue Aug 21 2012 Paul Howarth <paul@city-fan.org> - 1.000011-1
- Update to 1.000011
  - Fix various warning messages
- This release by APEIRON -> update source URL

* Mon Jul 30 2012 Paul Howarth <paul@city-fan.org> - 1.000010-1
- Update to 1.000010
  - Performance improvement: the creation of a Module::Metadata object
    for a typical module file has been sped up by about 40%%
  - Fix t/metadata.t failure under Cygwin
  - Portability fix-ups for new_from_module() and test failures on VMS
- This release by VPIT -> update source URL

* Fri Jun 29 2012 Paul Howarth <paul@city-fan.org> - 1.000009-3
- Drop explicit buildreqs for non-dual-lived modules
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> - 1.000009-1
- Update to 1.000009
  - API of 'provides' changed to require a 'version' argument to future
    proof the function against CPAN Meta Spec changes
  - Fatal errors now use 'croak' instead of 'die'; Carp added as
    prerequisite
- Improve %%description
- Include all buildreqs explicitly required and classify them by Build,
  Module, Regular test suite, and Release tests
- Only include explicit runtime dependency of perl(version) where it's needed

* Wed Feb  8 2012 Paul Howarth <paul@city-fan.org> - 1.000008-1
- Update to 1.000008
  - Adds 'provides' method to generate a CPAN META provides data structure
    correctly; use of package_versions_from_directory is discouraged

* Wed Sep  7 2011 Paul Howarth <paul@city-fan.org> - 1.000007-1
- Update to 1.000007
  - Apply VMS fixes backported from blead

* Sun Sep  4 2011 Paul Howarth <paul@city-fan.org> - 1.000006-1
- Update to 1.000006
  - Support PACKAGE BLOCK syntax

* Wed Aug  3 2011 Paul Howarth <paul@city-fan.org> - 1.000005-1
- Update to 1.000005
  - Localize $package::VERSION during version discovery
  - Fix references to Module::Build::ModuleInfo (CPAN RT#66133)
  - Added 'new_from_handle()' method (CPAN RT#68875)
  - Improved documentation (SYNOPSIS, broke out class/object method, and
    other minor edits)
- Install to vendor directories rather than perl directories

* Fri Jul  1 2011 Paul Howarth <paul@city-fan.org> - 1.000004-5
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Feb  3 2011 Paul Howarth <paul@city-fan.org> - 1.000004-1
- Update to 1.000004
  - Fix broken metadata.t when @INC has relative paths

* Tue Jan 25 2011 Paul Howarth <paul@city-fan.org> - 1.000003-1
- Initial RPM version
